summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/objects/object_factory.h')
-rw-r--r--kig/objects/object_factory.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kig/objects/object_factory.h b/kig/objects/object_factory.h
index d99cce8b..30f080d9 100644
--- a/kig/objects/object_factory.h
+++ b/kig/objects/object_factory.h
@@ -108,10 +108,10 @@ public:
/**
* this one does the same as the above, only that the new label is
* attached to locationtqparent if it is non-null..
*/
ObjectTypeCalcer* attachedLabelCalcer(
- const TQString& s, ObjectCalcer* locationtqparent,
+ const TQString& s, ObjectCalcer* locationparent,
const Coordinate& loc, bool needframe,
const std::vector<ObjectCalcer*>& parents,
const KigDocument& doc ) const;
@@ -121,11 +121,11 @@ public:
* attach point from the method above
*/
ObjectCalcer* getAttachPoint(
- ObjectCalcer* locationtqparent,
+ ObjectCalcer* locationparent,
const Coordinate& loc,
const KigDocument& doc ) const;
ObjectHolder* attachedLabel(
- const TQString& s, ObjectCalcer* locationtqparent,
+ const TQString& s, ObjectCalcer* locationparent,
const Coordinate& loc, bool needframe,
const std::vector<ObjectCalcer*>& parents,
const KigDocument& doc ) const;
@@ -108,10 +108,10 @@ public:
/**
* this one does the same as the above, only that the new label is
- * attached to locationtqparent if it is non-null..
+ * attached to locationparent if it is non-null..
*/
ObjectTypeCalcer* attachedLabelCalcer(